/*
 * 	TMP101.c
 *
 *	### For description see TMP101.h!!!
 *
 *  Created on: 16.10.2013
 *      Author: Mika Vyrynen
 */
#include "TMP101.h"

//------------------------------------------------------------------------------
// Initializes the TMP101.
//
// If no run time configurations are needed, then only this function
// is needed to be used.
//
// Function writes default settings to TMP101 configuration register. Settings can
// be edited in TMP101.h -file.
//------------------------------------------------------------------------------
void InitTMP101()
{
	unsigned char registerValues[2] =
			{
			CONFIGURATION_REGISTER,
			RESOLUTION_REGISTER_VALUE | SHUTDOWN_OFF | DEFAULT_POLARITY_BIT | THERMOSTAT_STARTUP_BIT};

	I2CMasterTransmit(TMP101_SLAVE_ADDRESS,registerValues,sizeof(registerValues));
}

//------------------------------------------------------------------------------
// Read temperature value from tmp101.
// Function returns the value which is read from the TMP101 temperature register.
// Value is not absolute temperature value but rather a conversion value from
// the TMP101 sensor.
//------------------------------------------------------------------------------
int GetTemperatureTMP101()
{
	unsigned char temperature[2];
	int retVal = 0;
	I2CMasterReadRegister(TMP101_SLAVE_ADDRESS,TEMPERATURE_REGISTER,temperature,2);
	retVal = temperature[0];
	retVal <<= 8;
	retVal |= temperature[1];
	return retVal >> 4;
}
// Set ALARM-pin polarity
//
// TMP101 allows the user to adjust the
// polarity of the ALERT pin output. If POL = 0, the ALERT pin
// will be active LOW. For POL = 1 the ALERT pin will be active HIGH,
// and the state of the ALERT pin is inverted.
void SetAlertPinPolarity(char polarity)
{
	unsigned char registerValues[2] = {CONFIGURATION_REGISTER, RESOLUTION_REGISTER_VALUE};
	if(polarity == POLARITY_ACTIVE_LOW)
	{
		registerValues[1] &= ~POLARITY_BIT;
	}
	else
	{
		registerValues[1] |= POLARITY_BIT;
	}
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS,registerValues,sizeof(registerValues));
}
//------------------------------------------------------------------------------
// Set high temperature limit
//
// Given value does not need any shifting, it is done within the function.
//
// Description in datasheet:
// In Comparator Mode (TM = 0), the ALERT pin of the
// TMP101 becomes active when the temperature equals or
// exceeds the value in THIGH and generates a consecutive
// number of faults according to fault bits F1 and F0. The
// ALERT pin will remain active until the temperature falls
// below the indicated TLOW value for the same number of
// faults.
// In Interrupt Mode (TM = 1) the ALERT Pin becomes active
// when the temperature equals or exceeds THIGH for a
// consecutive number of fault conditions. The ALERT pin
// remains active until a read operation of any register occurs
// or the device successfully responds to the SMBus Alert
// Response Address. The ALERT pin will also be cleared if
// the device is placed in Shutdown Mode. Once the ALERT
// pin is cleared, it will only become active again by the
// temperature falling below TLOW.
//------------------------------------------------------------------------------
void SetHighTempLimit(int value)
{
	unsigned char registerValues[3] = {TEMPERATURELIMIT_HIGH_REGISTER, 0,0};
	value <<= 4;
	registerValues[1] = (value >> 8);
	registerValues[2] = (char) value;
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}

//------------------------------------------------------------------------------
// Set low temperature limit
//
// Given value does not need any shifting, it is done within the function.
//
// Description in datasheet:
// In Comparator Mode (TM = 0), the ALERT pin of the
// TMP101 becomes active when the temperature equals or
// exceeds the value in THIGH and generates a consecutive
// number of faults according to fault bits F1 and F0. The
// ALERT pin will remain active until the temperature falls
// below the indicated TLOW value for the same number of
// faults.
// In Interrupt Mode (TM = 1) the ALERT Pin becomes active
// when the temperature equals or exceeds THIGH for a
// consecutive number of fault conditions. The ALERT pin
// remains active until a read operation of any register occurs
// or the device successfully responds to the SMBus Alert
// Response Address. The ALERT pin will also be cleared if
// the device is placed in Shutdown Mode. Once the ALERT
// pin is cleared, it will only become active again by the
// temperature falling below TLOW.
//------------------------------------------------------------------------------
void SetLowTempLimit(int value)
{
	unsigned char registerValues[3] = {TEMPERATURELIMIT_LOW_REGISTER, 0,0};
	value <<= 4;
	registerValues[1] = (value >> 8);
	registerValues[2] = (char) value;
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}

//------------------------------------------------------------------------------
// Set Fault limit. Appropriate values are 1,2,4 and 6. Other values makes no sense.
//
// A fault condition occurs when the measured temperature
// exceeds the user-defined limits set in the THIGH and TLOW
// Registers. Additionally, the number of fault conditions
// required to generate an alert may be programmed using
// the Fault Queue. The Fault Queue is provided to prevent
// a false alert due to environmental noise. The Fault Queue
// requires consecutive fault measurements in order to
// trigger the alert function.
//
//------------------------------------------------------------------------------
void SetFaultQueue(int value)
{
	unsigned char registerValues[2] = {CONFIGURATION_REGISTER, RESOLUTION_REGISTER_VALUE};
	switch(value)
	{
	case 1:
		registerValues[1] |= FAULT_BITS_1;		// this is actually useless command because FAULT_BITS_1 = 0
		break;
	case 2:
		registerValues[1] |= FAULT_BITS_2;
		break;
	case 4:
		registerValues[1] |= FAULT_BITS_4;
		break;
	case 6:
		registerValues[1] |= FAULT_BITS_6;
		break;
	default:
		// Nothing happens. Add error report here if wanted.
		break;
	}
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}

//------------------------------------------------------------------------------
// Set Thermostat mode.
// The Thermostat Mode bit of the TMP101 indicates to the
// device whether to operate in Comparator Mode (TM = 0)
// or Interrupt Mode (TM = 1).
//------------------------------------------------------------------------------
void SetThermostatMode(int onOff)
{
	unsigned char registerValues[2] = {CONFIGURATION_REGISTER, RESOLUTION_REGISTER_VALUE};
	if(onOff == 1)
	{
		registerValues[1] |= THERMOSTAT_MODE_BIT;
	}
	else
	{
		registerValues[1] &= ~THERMOSTAT_MODE_BIT;
	}
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}
//------------------------------------------------------------------------------
// Read OS-ALERT status bit.
//
// Reading the OS/ALERT bit will provide information about
// the Comparator Mode status. The state of the POL bit will
// invert the polarity of data returned from the OS/ALERT bit.
// For POL = 0, the OS/ALERT will read as 1 until the
// temperature equals or exceeds THIGH for the programmed
// number of consecutive faults, causing the OS/ALERT bit
// to read as 0. The OS/ALERT bit will continue to read as 0
// until the temperature falls below TLOW for the programmed
// number of consecutive faults when it will again read as 1.
// The status of the TM bit does not affect the status of the
// OS/ALERT bit.
//------------------------------------------------------------------------------
int GetOsAlertStatus()
{
	unsigned char configReg;
	I2CMasterReadRegister(TMP101_SLAVE_ADDRESS,CONFIGURATION_REGISTER,&configReg,1);
	if(configReg & OS_ALERT_BIT)
	{
		return 1;
	}
	else
	{
		return 0;
	}
}

//------------------------------------------------------------------------------
// Reset device to default power on settings.
// Tlow = 75 C degrees (default)
// Thigh = 85 C degrees (default)
//------------------------------------------------------------------------------
void ResetTMP101()
{
	unsigned char byte = RESET_DEVICE;
	I2CMasterTransmitWithoutAddress(&byte,1);
}

//------------------------------------------------------------------------------
// Set device to shut down mode to lower current consumption. Tlow and Thigh values are
// preserved in shutdown mode.
//
// The Shutdown Mode of the TMP100 and TMP101 allows
// the user to save maximum power by shutting down all
// device circuitry other than the serial interface, which
// reduces current consumption to less than 1uA.
//------------------------------------------------------------------------------
void ShutdownTMP101()
{
	unsigned char registerValues[2] = {CONFIGURATION_REGISTER, RESOLUTION_REGISTER_VALUE};
	registerValues[1] |= SHUTDOWN_ON;
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}

//------------------------------------------------------------------------------
// Wake up the device from the shutdown mode.
//------------------------------------------------------------------------------
void WakeUpTMP101()
{
	unsigned char registerValues[2] = {CONFIGURATION_REGISTER, RESOLUTION_REGISTER_VALUE};
	registerValues[1] &= ~SHUTDOWN_ON;
	I2CMasterTransmit(TMP101_SLAVE_ADDRESS, registerValues, sizeof(registerValues));
}
