/*
 * TMP101.h
 *
 * Description:
 *
 * This communication library provides functions which can be used when communicating
 * with TMP101 sensor. User can read temperature values and change operating mode, change
 * how ALARM-pin works and set the temperature limits.
 *
 *
 * In short: Include this file when TMP101 is used with MSP430 with USI I2C-
 * communication module.
 *
 * Note:
 * Change user settings (notified as "User: xxxx") whatever is needed and use the functions provided. It is recommended
 * to set the correct device in the project settings, because underlying USI-I2C includes only
 * <msp430.h> -library rather than spesific device.
 *
 * About:
 * This code is written on Windows 7 using Code Composer Studio v5. When
 * you change the code, it is recommended to ReBuild instead of Building or
 * do Clean -> Build.
 *
 *  	Created on: 	16.10.2013
 *      Modified:		19.10.2012
 *      Author: 		Mika Vyrynen
 *      Contact:		mika_va@hotmail.com / www.hutasu.net
 *      Version:		0.1	Created
 *      				0.2 Added functions
 *      					SetFaultQueue(int value);
 *      					SetThermostatMode(int onOff);
 *      					GetOsAlertStatus();
 *      					ResetTMP101();
 *
 *      					Tested OK.
 *
 */

#ifndef TMP101_H_
#define TMP101_H_

// Required communication library
#include "../USI/USI-I2C.h"

//------------------------------------------------------------------------------
// User: Change this to what is really connected to the ADD0-pin. Use FLOATING, HIGH or LOW only!
//------------------------------------------------------------------------------

#define ADD0_PIN	FLOATING

//------------------------------------------------------------------------------
// User: Set to desired resolution value. Use values 9,10,11 or 12 only! TMP101 Datasheet provides more info.
//------------------------------------------------------------------------------

#define TEMPERATURE_RESOLUTION	12			// Default power on value is 9

//------------------------------------------------------------------------------
// User: Select if the ALERT-polarity is high or low. TMP101 Datasheet provides more info.
//------------------------------------------------------------------------------
#define DEFAULT_POLARITY		LOW			// Default power on value is LOW

//------------------------------------------------------------------------------
// User: Select if the THERMOSTAT MODE is used. TMP101 Datasheet provides more info.
//------------------------------------------------------------------------------
#define THERMOSTAT_MODE			OFF			// Default power on value is OFF

//------------------------------------------------------------------------------
// DON'T TOUCH BELOW THIS LINE --- unless you know what you are doing
//------------------------------------------------------------------------------

#ifndef USI_I2C_H_
#error "YOU HAVE TO INCLUDE USI-I2C.h!!!"
#endif

#define FLOATING	2
#define HIGH		1
#define LOW			0

#define ON			1
#define OFF			0

// Changes slave address according to the ADD0-pin
#if ADD0_PIN == FLOATING
#define TMP101_SLAVE_ADDRESS				0x92
#endif
#if ADD0_PIN == HIGH
#define TMP101_SLAVE_ADDRESS				0x91
#endif
#if ADD0_PIN == LOW
#define TMP101_SLAVE_ADDRESS				0x90
#endif

// Device registers
#define TEMPERATURE_REGISTER				0x00
#define CONFIGURATION_REGISTER				0x01
#define TEMPERATURELIMIT_LOW_REGISTER		0x02
#define TEMPERATURELIMIT_HIGH_REGISTER		0x03

// resolution settings
#if TEMPERATURE_RESOLUTION == 9
#define RESOLUTION_REGISTER_VALUE			0x00
#define RESOLUTION_CALCULATION_VALUE			0.5		// 9 Bits = 0.5 C / tick
#endif
#if TEMPERATURE_RESOLUTION == 10
#define RESOLUTION_REGISTER_VALUE			0x20
#define RESOLUTION_CALCULATION_VALUE			0.25		// 10 Bits = 0.25 C / tick
#endif
#if TEMPERATURE_RESOLUTION == 11
#define RESOLUTION_REGISTER_VALUE			0x40
#define RESOLUTION_CALCULATION_VALUE			0.125		// 11 Bits = 0.125 C / tick
#endif
#if TEMPERATURE_RESOLUTION == 12
#define RESOLUTION_REGISTER_VALUE			0x60
#define RESOLUTION_CALCULATION_VALUE			0.0625		// 12 Bits = 0.0625 C / tick
#endif

// Fault bits
#define FAULT_BITS_1						0x00
#define FAULT_BITS_2						0x08
#define FAULT_BITS_4						0x10
#define FAULT_BITS_6						0x18


// Polarity
#if DEFAULT_POLARITY == LOW
#define DEFAULT_POLARITY_BIT				0x00
#endif
#if DEFAULT_POLARITY == HIGH
#define DEFAULT_POLARITY_BIT				0x04
#endif
#define POLARITY_ACTIVE_LOW					0
#define POLARITY_ACTIVE_HIGH				1

#define POLARITY_BIT						0x04

// Thermostat
#define THERMOSTAT_MODE_BIT					0x02
#if THERMOSTAT_MODE == ON
#define THERMOSTAT_STARTUP_BIT				THERMOSTAT_MODE_BIT
#else
#define THERMOSTAT_STARTUP_BIT				0x00
#endif

// OS/ALERT bit (OS)
#define OS_ALERT_BIT						0x80

// Shutdown
#define SHUTDOWN_ON							0x01
#define SHUTDOWN_OFF						0x00

// reset
#define RESET_DEVICE						0x06

//------------------------------------------------------------------------------
// Function prototypes
//------------------------------------------------------------------------------
void InitTMP101();
int GetTemperatureTMP101();
void SetAlertPinPolarity(char polarity);
void SetHighTempLimit(int value);
void SetLowTempLimit(int value);
void SetFaultQueue(int value);
void SetThermostatMode(int onOff);
int GetOsAlertStatus();
void ResetTMP101();
void ShutdownTMP101();
void WakeUpTMP101();

#endif /* TMP101_H_ */
