/*
 * 	MSP430G2231 USI I2C-Master Example
 *
 *	Eng: This code is an simple I2C-master example for MSP430G2231 MCU
 *		 for reading temperature values from TMP101 sensor.
 *		 Chip is connected as shown below and the communication is done
 *		 with I2C-bus.
 *
 * 	Fin: Yksinkertainen I2C-vyln esimerkkikoodi. Lue tarkemmat tiedot alla
 * 		 olevasta linkist.
 *
 * Note:
 * 		Change user settings whatever is needed and use the functions provided. It is recommended
 * 		to set the correct device in the project settings, because underlying USI-I2C includes only
 * 		<msp430.h> -library rather than a specific device.
 *
 * 		HW requires 32 kHz crystal on the Launchpad.
 *
 * About:
 * 		This code is written on Windows 7 using Code Composer Studio v5. When
 * 		you change the code, it is recommended to ReBuild instead of Building or
 * 		do Clean -> Build.
 *
 *
 *		MASTER 						  TMP101
 *		(Launchpad)
 * 	 	 ______                       ______
 * 		|  VCC |--------- VCC -------|4     |
 * 		|  P1.7|--------- SDA -------|6     |
 * 		|  P1.6|--------  SCL -------|1     |
 * 		|  P1.3|-------  ALERT ------|3     |
 *	    |  GND |--------  GND -------|2     |
 *	 	|	   |					 |______|
 *	 	|      |
 *	 	|      |
 *	 	|  P1.4|----|>------[270R]-----GND
 *		|______|  Gr. LED
 *
 *
 * 	Tarkemmat tiedot / More information:
 * 	http://www.hutasu.net/index.php?sivu_id=111&parent=8
 *
 * 	Flash/RAM 	= 1560/71 	bytes
 * 	INFOB		= 59/5 		(used/left) bytes
 *
 **/
#include <msp430.h>

#include "Launchpad/launchpad.h"
#include "Launchpad/UART.h"
#include "TMP101/TMP101.h"

// Store some text into INFO-memory section
#pragma DATA_SECTION(SlaveNotFoundText, ".infoB")
const char SlaveNotFoundText[] = "Slave Not Found!\r\n\0";
#pragma DATA_SECTION(SlaveFoundText, ".infoB")
const char SlaveFoundText[] = "Slave Found!\r\n\0";
#pragma DATA_SECTION(AlarmText, ".infoB")
const char AlarmText[] = "ALARM!\r\n\0";
#pragma DATA_SECTION(OkText, ".infoB")
const char OkText[] = "I'm fine!\r\n\0";
#pragma DATA_SECTION(MasterReadyText, ".infoC")
const char MasterReadyText[] = "Master Ready!\r\n\0";



int main(void)
{
	unsigned char wait = 1;
	//int temperature = 0;

    WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer

    // Init launchpad LEDS and S2
    InitGPIO();

    // Init timer for uart and delay
    TimerA_UART_pinInit();
    TimerA_UART_init();

    // Init USI for I2C Master
    InitUSI();

    // Init TMP101
    InitTMP101();

    // reset device with software
    ResetTMP101();

    // Tell user that we are ready
    TimerA_UART_print( (char *) MasterReadyText);

    // Check if slave exists, if not then do not proceed and turn on the error led
    while(CheckForSlaveExists(TMP101_SLAVE_ADDRESS) == 0)
	{
    	TimerA_UART_print( (char *) SlaveNotFoundText);
    	TimerA_Delay(1);
    	LED_RED_ON;
	}
    TimerA_UART_print((char *) SlaveFoundText);

    // Set Alarm values for the ALARM-pin
    SetHighTempLimit( (30 / RESOLUTION_CALCULATION_VALUE) ); // 30 degrees of Celsius limit, 30 = 480 (12-bit resolution)
    SetLowTempLimit( (28 / RESOLUTION_CALCULATION_VALUE) ); // 28 degrees of Celsius limit, 28 = 448 (12-bit resolution)

    // Set ALERT pin polarity "0" to simulate the button press
    SetAlertPinPolarity(0);

    // Set Fault queue
    SetFaultQueue(6);

    // Set thermostat mode
    SetThermostatMode(0);

while(1)
{
	/* Commented out on purpose.

	// Read the temperature
	temperature = GetTemperatureTMP101();

	// Compare temperature
	if(temperature > (30 / RESOLUTION_CALCULATION_VALUE)) // 26 degrees of Celsius
	{
		TimerA_UART_print("Temp Over 30\r\n\0");
	}
	else
	{
		TimerA_UART_print("Temp Under 30\r\n\0");
	}

	*/
	WakeUpTMP101();
	TimerA_Delay(wait);
	// If ALERT-pin is active, ALARM! text is printed to UART
	if(SWITCH_PRESSED)
	{
		TimerA_UART_print((char *) AlarmText);
		P1OUT &= ~BIT4;
	}
	else
	{
		TimerA_UART_print((char *) OkText);
		P1OUT |= BIT4;
	}
	// Sleep one second
	ShutdownTMP101();
}
}
